#include <curl/curl.h>

#include "histogram.h"
#include "text.h"
#include "svg.h"

struct Input {
    vector<double> vec;
    size_t korz{};
};

Input input_data(istream& in, bool prompt = false) {
    Input lin;
    size_t n, korz;
    if(prompt)
        cerr << "Number of elements: ";
    in >> n;
    lin.vec.resize(n);
    for (size_t i = 0; i < n; i++)
        in >> lin.vec[i];
    if(prompt)
        cerr << "Enter bin count: ";
    in >> lin.korz;
    return lin;
}

int main(int argc, char* argv[]) {
    if (argc > 1) {
        CURL* curl = curl_easy_init();
        if (curl) {
            curl_easy_setopt(curl, CURLOPT_URL, argv[1]);

            CURLcode res = curl_easy_perform(curl);
            if (res != CURLE_OK) {
                cerr << "cURL error: " << curl_easy_strerror(res) << endl;
                exit(1);
            }

            curl_easy_cleanup(curl);
        } else {
            cerr << "curl_easy_init() failed" << endl;
        }
        return 0;
    }

    auto in = input_data(cin);
    auto bins = make_histogram(in.korz, in.vec);
    show_histogram_svg(bins);
    return 0;
}

//  .   ,    ( )    .
//       ,  , ,      ,  .
//    ,         .
// NUL           .

/*
C:\Users\Natasha\Desktop\ 2\cs-lab34\bin\Debug>cs-lab34.exe -x --y /z w
argc = 5
argv[0] = cs-lab34.exe
argv[1] = -x
argv[2] = --y
argv[3] = /z
argv[4] = w

C:\Users\Natasha\Desktop\ 2\cs-lab34\bin\Debug>cs-lab34.exe param "with spaces"
argc = 3
argv[0] = cs-lab34.exe
argv[1] = param
argv[2] = with spaces

C:\Users\Natasha\Desktop\ 2\cs-lab34\bin\Debug>cs-lab34.exe param <marks.txt >NUL
*/
